
Single application-level logging
-------

**Description:**

Whenever the application contains a single application-level logging implementation it 
becomes clear and transparent and easy to maintain, also it reduces the possibility you 
overlook high priority logging.


**Solution:**

Verify that there is a single application-level logging implementation that is used by 
the software.